#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Mar 10 13:18:40 2022

@author: anton
"""

from SLiCAP import *

RHO = 16.8e-9 # Specific resistance copper Ohm.m
L   = 1       # Supply cable length
d   = 0.5e-3  # Supply cable diameter
Ce  = 10e-6   # Capacitance of electrolytic capacitor
Re  = 0.5     # ESR of electrolytic capacitor
Le  = 20e-9   # ESL of electrolytic capacitor
Cc  = 100e-9  # Capacitance of ceramic capacitor
Lc  = 3e-9    # ESL of ceramic capacitor
Rc  = 0.05    # ESR of ceramic capacitor

fileName = "supplyDecoupling"

prj = initProject(fileName)

#makeNetlist(fileName + ".asc", "Supply Decoupling")

# Define the instruction and the circuit
i1 = instruction()
i1.setCircuit(fileName + ".cir")
# Define the circuit parameters
i1.defPar("rho_c", RHO)
i1.defPar("L", L)
i1.defPar("d", d)
i1.defPar("C_e", Ce)
i1.defPar("R_e", Re)
i1.defPar("L_e", Le)
i1.defPar("C_c", Cc)
i1.defPar("R_c", Rc)
i1.defPar("L_c", Lc)
# Define the instruction details
i1.setSimType("numeric")
i1.setDataType("laplace")
i1.setGainType("gain")
i1.setDetector("V_out")
# Plot the impedance versus frequency
i1.setSource("I1")
result = i1.execute()
figZ = plotSweep("figZ", "Magnitude of the supply impedance versus frequency", result, 0.001, 1e3, 200, sweepScale="M", funcType="mag", show=True)
# Plot the voltage transfer versus frequency
i1.setSource("V1")
result = i1.execute()
figT = plotSweep("figT", "Magnitude of voltage transfer versus frequency", result, 0.001, 1e3, 200, sweepScale="M", funcType="mag", show=True)

htmlPage("Circuit data")
head2html("Circuit diagram")
img2html(fileName + ".svg", 800)
netlist2html(fileName + ".cir")
elementData2html(i1.circuit)
params2html(i1.circuit)
htmlPage("Magnitude plots")
fig2html(figZ, 800)
fig2html(figT, 800)